@@ -1,6 +1,6 @@
 package Rinci;
 
-our $VERSION = '1.1.95'; # VERSION
+our $VERSION = '1.1.97'; # VERSION
 
 1;
 # ABSTRACT: Language-neutral metadata for your code
@@ -17,7 +17,7 @@ Rinci - Language-neutral metadata for your code
 
 =head1 VERSION
 
-This document describes version 1.1.95 of Rinci (from Perl distribution Rinci), released on 2020-10-01.
+This document describes version 1.1.97 of Rinci (from Perl distribution Rinci), released on 2021-01-22.
 
 =head1 HOMEPAGE
 
@@ -29,7 +29,7 @@ Source repository is at L<https://github.com/perlancar/perl-Rinci>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Rinci>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Rinci/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -41,7 +41,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
